@@ -72,7 +72,10 @@ class Feed2Twitter(object):
         if not lastread:
             self.twitIt(reversed(self.rss.feed['items'][:5]))
         else:
-            lista = [item for item in self.rss.feed['items'] if item['updated_parsed'] > lastread]
+            try:
+                lista = [item for item in self.rss.feed['items'] if item['published_parsed'] > lastread]
+            except:
+                lista = [item for item in self.rss.feed['items'] if item['updated_parsed'] > lastread]
             self.twitIt(reversed(lista[:5]))
 
 def update():
